'use strict';

/* jshint quotmark: double */
window.SwaggerTranslator.learn({
    "Warning: Deprecated":"Advertència: Obsolet",
    "Implementation Notes":"Notes d'implementació",
    "Response Class":"Classe de la Resposta",
    "Status":"Estatus",
    "Parameters":"Paràmetres",
    "Parameter":"Paràmetre",
    "Value":"Valor",
    "Description":"Descripció",
    "Parameter Type":"Tipus del Paràmetre",
    "Data Type":"Tipus de la Dada",
    "Response Messages":"Missatges de la Resposta",
    "HTTP Status Code":"Codi d'Estatus HTTP",
    "Reason":"Raó",
    "Response Model":"Model de la Resposta",
    "Request URL":"URL de la Sol·licitud",
    "Response Body":"Cos de la Resposta",
    "Response Code":"Codi de la Resposta",
    "Response Headers":"Capçaleres de la Resposta",
    "Hide Response":"Amagar Resposta",
    "Try it out!":"Prova-ho!",
    "Show/Hide":"Mostrar/Amagar",
    "List Operations":"Llista Operacions",
    "Expand Operations":"Expandir Operacions",
    "Raw":"Cru",
    "can't parse JSON.  Raw result":"no puc analitzar el JSON.  Resultat cru",
    "Example Value":"Valor d'Exemple",
    "Model Schema":"Esquema del Model",
    "Model":"Model",
    "apply":"aplicar",
    "Username":"Nom d'usuari",
    "Password":"Contrasenya",
    "Terms of service":"Termes del servei",
    "Created by":"Creat per",
    "See more at":"Veure més en",
    "Contact the developer":"Contactar amb el desenvolupador",
    "api version":"versió de la api",
    "Response Content Type":"Tipus de Contingut de la Resposta",
    "fetching resource":"recollint recurs",
    "fetching resource list":"recollins llista de recursos",
    "Explore":"Explorant",
    "Show Swagger Petstore Example Apis":"Mostrar API d'Exemple Swagger Petstore",
    "Can't read from server.  It may not have the appropriate access-control-origin settings.":"No es pot llegir del servidor. Potser no teniu la configuració de control d'accés apropiada.",
    "Please specify the protocol for":"Si us plau, especifiqueu el protocol per a",
    "Can't read swagger JSON from":"No es pot llegir el JSON de swagger des de",
    "Finished Loading Resource Information. Rendering Swagger UI":"Finalitzada la càrrega del recurs informatiu. Renderitzant Swagger UI",
    "Unable to read api":"No es pot llegir l'api",
    "from path":"des de la ruta",
    "server returned":"el servidor ha retornat"
});
